from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

version_file = open(os.path.join(here, 'hydroid', 'VERSION'))
version = version_file.read().strip()

# Get the long description from the relevant file
with codecs.open(os.path.join(here, 'DESCRIPTION.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='hydroid',

    # Versions should comply with PEP440. For single-sourced versioning, see
    # http://packaging.python.org/en/latest/tutorial.html#version
    version=version,

    description='HYDROID (HYDroxyl-Radical fOotprinting Interpretation for DNA) is a python package for the analysis of experimental data generated by hydroxyl-radical footprinting (HRF) of DNA-protein complexes',
    long_description=long_description,

    # The project URL.
    url='https://github.com/ncbi/HYDROID',

    # Author details
    author='Alexey K. Shaytan, Grigoriy A. Armeev, David Landsman, Anna R. Panchenko',
    author_email='alex@intbio.org',

    # Choose your license
    license='Public Domain',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # https://pypi.python.org/pypi?%3Aaction=list_classifiers
        # Project maturity. 
        'Development Status :: 3 - Alpha',

        # Intended audience
        'Intended Audience :: Science/Research',

        # Topic
        'Topic :: Scientific/Engineering :: Bio-Informatics',

        # License should match "license" above
        'License :: Public Domain',

        # Python versions supported
        'Programming Language :: Python :: 2.7',
    ],

    # What does your project relate to?
    keywords='science hydroxyl-radical footprinting image analysis',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['examples', 'docs', 'tests*']),

    # Run-time package dependencies. These will be installed by pip when your
    # project is installed.
    install_requires=[
        'biopython==1.68',
        'matplotlib==2.0.0',
        'numpy>=1.11.0',
        'pandas>=0.19.2',
        'PeakUtils>=1.0.3',
        'Pillow==4.0.0',
        'scipy==0.18.1',
        'statsmodels==0.8.0',
    ],
    extras_require = {
    'pred': [
        'Cython',
    ],},

    # Data files included in your packages. If using Python 2.6 or less, 
    # then these have to be included in MANIFEST.in as well.
    package_data={
        'hydroid': ['pkgdata/amber10_rmin.config','pkgdata/charmm36_rmin.config','pkgdata/cnr.otf','pkgdata/cnrb.otf'],
    },

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'HYDROID_test_exp=hydroid.command_line:test_exp',
            'HYDROID_test_pred=hydroid.command_line:test_pred',
            'HYDROID_get_ex1=hydroid.command_line:HYDROID_get_ex1',
            'HYDROID_get_ex2=hydroid.command_line:HYDROID_get_ex2',

        ],
    },
    python_requires='==2.7.*',
    # MANIFEST.in included entries should be included as package data and
    # installed into site-packages 
    include_package_data=True,

    # Default to False unless you specifically intend the package to be
    # installed as an .egg
    zip_safe=False,
)
